pub struct FileConfig;Expand description
Makes Redoc load it’s configuration from a user defined file.
The config file must be defined via UTOIPA_REDOC_CONFIG_FILE env variable for your
application. It can either be defined in runtime before the Redoc declaration or before
application startup or at compile time via build.rs file.
The file must be located relative to your application runtime directory.
The file must be loadable via Config and it must return a JSON object representing the
Redoc configuration.
Examples
Using a build.rs file to define the config file.
println!("cargo:rustc-env=UTOIPA_REDOC_CONFIG_FILE=redoc.config.json");Defining config file at application startup.
UTOIPA_REDOC_CONFIG_FILE=redoc.config.json cargo runTrait Implementations
Sourceimpl Config for FileConfig
impl Config for FileConfig
Sourcefn load(self) -> Value
fn load(self) -> Value
serde_json::Value.Auto Trait Implementations
impl Freeze for FileConfig
impl RefUnwindSafe for FileConfig
impl Send for FileConfig
impl Sync for FileConfig
impl Unpin for FileConfig
impl UnsafeUnpin for FileConfig
impl UnwindSafe for FileConfig